@@ -10,7 +10,7 @@
 # ABSTRACT: List applications handled by cme
 
 package App::Cme::Command::list ;
-$App::Cme::Command::list::VERSION = '1.009';
+$App::Cme::Command::list::VERSION = '1.011';
 use strict;
 use warnings;
 use 5.10.1;
@@ -29,6 +29,13 @@ EOD
 
 }
 
+sub opt_spec {
+    my ( $class, $app ) = @_;
+    return (
+        [ "dev!"               => "list includes a model under development"],
+    );
+}
+
 my %help = (
     system => "system configuration files. Use sudo to run cme",
     user => "user configuration files",
@@ -60,7 +67,7 @@ App::Cme::Command::list - List applications handled by cme
 
 =head1 VERSION
 
-version 1.009
+version 1.011
 
 =head1 SYNOPSIS
 
