@@ -10,7 +10,7 @@
 # ABSTRACT: Update the configuration of an application
 
 package App::Cme::Command::update ;
-$App::Cme::Command::update::VERSION = '1.009';
+$App::Cme::Command::update::VERSION = '1.011';
 use strict;
 use warnings;
 use 5.10.1;
@@ -21,7 +21,7 @@ use base qw/App::Cme::Common/;
 
 use Config::Model::ObjTreeScanner;
 
-use Config::Model 2.068; # for call to Instance->update
+use Config::Model;
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
@@ -91,7 +91,7 @@ App::Cme::Command::update - Update the configuration of an application
 
 =head1 VERSION
 
-version 1.009
+version 1.011
 
 =head1 SYNOPSIS
 
