@@ -10,12 +10,12 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.009';
+$App::Cme::Common::VERSION = '1.011';
 use strict;
 use warnings;
 use 5.10.1;
 
-use Config::Model 2.063;
+use Config::Model 2.077;
 use Config::Model::Lister;
 use Pod::POM;
 use Pod::POM::View::Text;
@@ -94,6 +94,9 @@ sub process_args {
         shift @$args;
     }
 
+    # override (or specify) configuration dir
+    $opt->{_config_dir} = $appli_info->{$application}{config_dir};
+
     $opt->{_application} = $application ;
     $opt->{_config_file} = $config_file;
     $opt->{_root_model}  = $root_model;
@@ -119,10 +122,10 @@ sub instance {
             root_dir        => $opt->{root_dir},
             check           => $opt->{force_load} ? 'no' : 'yes',
             auto_create     => $opt->{create},
-            skip_read       => $opt->{load} ? 1 : 0,
             backend         => $opt->{backend},
             backup          => $opt->{backup},
             config_file     => $opt->{_config_file},
+            config_dir      => $opt->{_config_dir},
         );
 
 }
@@ -218,7 +221,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.009
+version 1.011
 
 =head1 SYNOPSIS
 
